==> qt6-qtdeclarative-6.6.1.tgz: lib/cmake/Qt6QmlTools/Qt6QmlToolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::qmlcachegen" for configuration "Release"
set_property(TARGET Qt6::qmlcachegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlcachegen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/qmlcachegen"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlcachegen )
list(APPEND _cmake_import_check_files_for_Qt6::qmlcachegen "${_IMPORT_PREFIX}/lib/qt6/libexec/qmlcachegen" )

# Import target "Qt6::qmldom" for configuration "Release"
set_property(TARGET Qt6::qmldom APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmldom PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmldom"
  )

list(APPEND _cmake_import_check_targets Qt6::qmldom )
list(APPEND _cmake_import_check_files_for_Qt6::qmldom "${_IMPORT_PREFIX}/lib/qt6/bin/qmldom" )

# Import target "Qt6::qmllint" for configuration "Release"
set_property(TARGET Qt6::qmllint APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmllint PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmllint"
  )

list(APPEND _cmake_import_check_targets Qt6::qmllint )
list(APPEND _cmake_import_check_files_for_Qt6::qmllint "${_IMPORT_PREFIX}/lib/qt6/bin/qmllint" )

# Import target "Qt6::qmltc" for configuration "Release"
set_property(TARGET Qt6::qmltc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmltc PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmltc"
  )

list(APPEND _cmake_import_check_targets Qt6::qmltc )
list(APPEND _cmake_import_check_files_for_Qt6::qmltc "${_IMPORT_PREFIX}/lib/qt6/bin/qmltc" )

# Import target "Qt6::qmltyperegistrar" for configuration "Release"
set_property(TARGET Qt6::qmltyperegistrar APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmltyperegistrar PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/qmltyperegistrar"
  )

list(APPEND _cmake_import_check_targets Qt6::qmltyperegistrar )
list(APPEND _cmake_import_check_files_for_Qt6::qmltyperegistrar "${_IMPORT_PREFIX}/lib/qt6/libexec/qmltyperegistrar" )

# Import target "Qt6::qmlimportscanner" for configuration "Release"
set_property(TARGET Qt6::qmlimportscanner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlimportscanner PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/qmlimportscanner"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlimportscanner )
list(APPEND _cmake_import_check_files_for_Qt6::qmlimportscanner "${_IMPORT_PREFIX}/lib/qt6/libexec/qmlimportscanner" )

# Import target "Qt6::qmlformat" for configuration "Release"
set_property(TARGET Qt6::qmlformat APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlformat PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmlformat"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlformat )
list(APPEND _cmake_import_check_files_for_Qt6::qmlformat "${_IMPORT_PREFIX}/lib/qt6/bin/qmlformat" )

# Import target "Qt6::qmlprofiler" for configuration "Release"
set_property(TARGET Qt6::qmlprofiler APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlprofiler PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmlprofiler"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlprofiler )
list(APPEND _cmake_import_check_files_for_Qt6::qmlprofiler "${_IMPORT_PREFIX}/lib/qt6/bin/qmlprofiler" )

# Import target "Qt6::qmltime" for configuration "Release"
set_property(TARGET Qt6::qmltime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmltime PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmltime"
  )

list(APPEND _cmake_import_check_targets Qt6::qmltime )
list(APPEND _cmake_import_check_files_for_Qt6::qmltime "${_IMPORT_PREFIX}/lib/qt6/bin/qmltime" )

# Import target "Qt6::qmlplugindump" for configuration "Release"
set_property(TARGET Qt6::qmlplugindump APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlplugindump PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmlplugindump"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlplugindump )
list(APPEND _cmake_import_check_files_for_Qt6::qmlplugindump "${_IMPORT_PREFIX}/lib/qt6/bin/qmlplugindump" )

# Import target "Qt6::qmltestrunner" for configuration "Release"
set_property(TARGET Qt6::qmltestrunner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmltestrunner PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmltestrunner"
  )

list(APPEND _cmake_import_check_targets Qt6::qmltestrunner )
list(APPEND _cmake_import_check_files_for_Qt6::qmltestrunner "${_IMPORT_PREFIX}/lib/qt6/bin/qmltestrunner" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> qt6-qtdeclarative-6.7.3p0.tgz: lib/cmake/Qt6QmlTools/Qt6QmlToolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::qmlcachegen" for configuration "Release"
set_property(TARGET Qt6::qmlcachegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlcachegen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/qmlcachegen"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlcachegen )
list(APPEND _cmake_import_check_files_for_Qt6::qmlcachegen "${_IMPORT_PREFIX}/lib/qt6/libexec/qmlcachegen" )

# Import target "Qt6::qmldom" for configuration "Release"
set_property(TARGET Qt6::qmldom APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmldom PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmldom"
  )

list(APPEND _cmake_import_check_targets Qt6::qmldom )
list(APPEND _cmake_import_check_files_for_Qt6::qmldom "${_IMPORT_PREFIX}/lib/qt6/bin/qmldom" )

# Import target "Qt6::qmllint" for configuration "Release"
set_property(TARGET Qt6::qmllint APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmllint PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmllint"
  )

list(APPEND _cmake_import_check_targets Qt6::qmllint )
list(APPEND _cmake_import_check_files_for_Qt6::qmllint "${_IMPORT_PREFIX}/lib/qt6/bin/qmllint" )

# Import target "Qt6::qmltc" for configuration "Release"
set_property(TARGET Qt6::qmltc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmltc PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmltc"
  )

list(APPEND _cmake_import_check_targets Qt6::qmltc )
list(APPEND _cmake_import_check_files_for_Qt6::qmltc "${_IMPORT_PREFIX}/lib/qt6/bin/qmltc" )

# Import target "Qt6::qmltyperegistrar" for configuration "Release"
set_property(TARGET Qt6::qmltyperegistrar APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmltyperegistrar PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/qmltyperegistrar"
  )

list(APPEND _cmake_import_check_targets Qt6::qmltyperegistrar )
list(APPEND _cmake_import_check_files_for_Qt6::qmltyperegistrar "${_IMPORT_PREFIX}/lib/qt6/libexec/qmltyperegistrar" )

# Import target "Qt6::qmljsrootgen" for configuration "Release"
set_property(TARGET Qt6::qmljsrootgen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmljsrootgen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/qmljsrootgen"
  )

list(APPEND _cmake_import_check_targets Qt6::qmljsrootgen )
list(APPEND _cmake_import_check_files_for_Qt6::qmljsrootgen "${_IMPORT_PREFIX}/lib/qt6/libexec/qmljsrootgen" )

# Import target "Qt6::qmlimportscanner" for configuration "Release"
set_property(TARGET Qt6::qmlimportscanner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlimportscanner PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/qmlimportscanner"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlimportscanner )
list(APPEND _cmake_import_check_files_for_Qt6::qmlimportscanner "${_IMPORT_PREFIX}/lib/qt6/libexec/qmlimportscanner" )

# Import target "Qt6::qmlformat" for configuration "Release"
set_property(TARGET Qt6::qmlformat APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlformat PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmlformat"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlformat )
list(APPEND _cmake_import_check_files_for_Qt6::qmlformat "${_IMPORT_PREFIX}/lib/qt6/bin/qmlformat" )

# Import target "Qt6::qmlprofiler" for configuration "Release"
set_property(TARGET Qt6::qmlprofiler APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlprofiler PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmlprofiler"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlprofiler )
list(APPEND _cmake_import_check_files_for_Qt6::qmlprofiler "${_IMPORT_PREFIX}/lib/qt6/bin/qmlprofiler" )

# Import target "Qt6::qmltime" for configuration "Release"
set_property(TARGET Qt6::qmltime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmltime PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmltime"
  )

list(APPEND _cmake_import_check_targets Qt6::qmltime )
list(APPEND _cmake_import_check_files_for_Qt6::qmltime "${_IMPORT_PREFIX}/lib/qt6/bin/qmltime" )

# Import target "Qt6::qmlplugindump" for configuration "Release"
set_property(TARGET Qt6::qmlplugindump APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmlplugindump PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmlplugindump"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlplugindump )
list(APPEND _cmake_import_check_files_for_Qt6::qmlplugindump "${_IMPORT_PREFIX}/lib/qt6/bin/qmlplugindump" )

# Import target "Qt6::qmltestrunner" for configuration "Release"
set_property(TARGET Qt6::qmltestrunner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmltestrunner PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmltestrunner"
  )

list(APPEND _cmake_import_check_targets Qt6::qmltestrunner )
list(APPEND _cmake_import_check_files_for_Qt6::qmltestrunner "${_IMPORT_PREFIX}/lib/qt6/bin/qmltestrunner" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
